@@ -1,5 +1,5 @@
 from importlib.metadata import version as get_version
 
-from . import evals, solvers
+from . import evals
 
 __version__ = get_version("astabench")
